@@ -1,5 +1,6 @@
 from .addons import AddonsStream
 from .coupons import CouponsStream
+from .comments import CommentsStream
 from .credit_notes import CreditNotesStream
 from .customers import CustomersStream
 from .events import EventsStream
@@ -15,10 +16,12 @@ from .virtual_bank_accounts import VirtualBankAccountsStream
 from .credit_notes import CreditNotesStream
 from .gifts import GiftsStream
 from .orders import OrdersStream
+from .quotes import QuotesStream
 from .promotional_credits import PromotionalCreditsStream
 
 COMMON_AVAILABLE_STREAMS = [
     EventsStream,
+    CommentsStream,
     CouponsStream,
     CreditNotesStream,
     CustomersStream,
@@ -26,6 +29,7 @@ COMMON_AVAILABLE_STREAMS = [
     InvoicesStream,
     OrdersStream,
     PaymentSourcesStream,
+    QuotesStream,
     PromotionalCreditsStream,
     SubscriptionsStream,
     TransactionsStream,
