@@ -12,6 +12,13 @@ class SubscriptionsStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'plan_model/subscriptions'
+    SORT_BY = 'updated_at'
+
+    def __init__(self, config, state, catalog, client):
+        BaseChargebeeStream.__init__(self, config, state, catalog, client)
+        if self.config['item_model']:
+            self.SCHEMA = 'item_model/subscriptions'
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/subscriptions'.format(self.config.get('site'))
